@@ -198,60 +198,57 @@ def _main():
             find_new_git_url.find_urls(find_new_git_url_answers)
 
         else:
-            jenkins_questions = [{
-                'type': 'confirm',
-                'name': 'update_jenkins_job',
-                'message': 'Update Jenkins Job with new repo',
-                'default': True
-            }]
-            jenkins_questions_answers = prompt(jenkins_questions, style=style)
 
-            if jenkins_questions_answers.get('update_jenkins_job'):
-                questions = [
+            questions = [
 
-                    {
-                        'type': 'input',
-                        'name': 'jenkins_url',
-                        'message': 'BMX Jenkins URL'
-                    },
-                    {
-                        'type': 'password',
-                        'name': 'jenkins_token',
-                        'message': 'Jenkins Token'
-                    },
-                    {
-                        'type': 'input',
-                        'name': 'jenkins_username',
-                        'message': 'Jenkins Username',
-                        'default': 'change_it@nike.com'
-                    },
-                    {
-                        'type': 'input',
-                        'name': 'new_org',
-                        'message': 'New Github Org',
-                        'default': 'nike-internal'
-                    },
-                    {
-                        'type': 'input',
-                        'name': 'old_org',
-                        'message': 'Old Github Org(s). Provide comma separated values ',
-                        'default': 'mp-commerce-fulfillment'
-                    },
-                    {
-                        'type': 'input',
-                        'name': 'team_prefix',
-                        'message': 'Team Prefix',
-                        'default': 'fulfillment'
-                    },
-                    {
-                        'type': 'input',
-                        'name': 'new_credentials_id',
-                        'message': 'Provide the new credentials to Change credentials id. Leave blank if not changing ',
-                        'default': ''
-                    }
-                ]
-                jenkins_answers = prompt(questions, style=style)
-                jenkins_migration.get_jobs(jenkins_answers)
+                {
+                    'type': 'input',
+                    'name': "jenkins_url",
+                    'message': "Provide the jenkins url"
+                },
+                {
+                    'type': 'input',
+                    'name': "path_to_data",
+                    'message': "Provide the file with the list of jobs. Leave blank if you want to reconfigure all jobs in the jenkins instance"
+                },
+                {
+                    'type': 'password',
+                    'name': 'jenkins_token',
+                    'message': 'Jenkins Token'
+                },
+                {
+                    'type': 'input',
+                    'name': 'jenkins_username',
+                    'message': 'Jenkins Username',
+                    'default': 'change_it@nike.com'
+                },
+                {
+                    'type': 'input',
+                    'name': 'new_org',
+                    'message': 'New Github Org',
+                    'default': 'nike-internal'
+                },
+                {
+                    'type': 'input',
+                    'name': 'old_org',
+                    'message': 'Old Github Org(s). Provide comma separated values ',
+                    'default': 'mp-commerce-fulfillment'
+                },
+                {
+                    'type': 'input',
+                    'name': 'team_prefix',
+                    'message': 'Team Prefix',
+                    'default': 'fulfillment'
+                },
+                {
+                    'type': 'input',
+                    'name': 'new_credentials_id',
+                    'message': 'Provide the new credentials to Change credentials id. Leave blank if not changing ',
+                    'default': ''
+                }
+            ]
+            jenkins_answers = prompt(questions, style=style)
+            jenkins_migration.get_jobs(jenkins_answers)
 
     except Exception as ex:
         traceback.print_exc()
