@@ -32,7 +32,7 @@ accept_header = "application/vnd.github.mercy-preview+json"
 errors = []
 
 s = requests.Session()
-retries = Retry(total=5, backoff_factor=2, status_forcelist=[404, 422])
+retries = Retry(total=5, backoff_factor=2, status_forcelist=[404, 422, 403])
 s.mount('https://', HTTPAdapter(max_retries=retries))
 
 
